@@ -15,6 +15,7 @@
 
 
 import argparse
+import hashlib
 import logging
 import os
 import time
@@ -51,6 +52,31 @@ class Tools(object):
                 org_dict[item]=input("please input your %s:"%item)
         return org_dict
 
+    @staticmethod
+    def input_password(org_dict:dict,items:list,salt="misas")->dict:
+        '''
+        
+        输入相应的参数
+
+        Args:
+            org_dict (dict): the dictionary of items
+            items (list): should check items list
+
+        Returns:
+            dict: updated dict
+        
+        >>> d={}
+        >>> Tools.input_password(d,["password"],salt="aijieofof")
+        >>> d["password"]
+        dlasf
+        '''
+        for item in items:
+            if not org_dict.get(item,None):
+                temps = input("please input your %s:"%item)
+                md5_value = hashlib.md5((salt+temps).encode('utf8')).hexdigest()
+                org_dict[item] = md5_value
+        return org_dict
+
     @staticmethod
     def get_config_from_args(options):
         config = {"brain_ip":options.brain_ip,"brain_port":int(options.brain_port),
